==> SyL-0.12.1.tar.gz: SyL/example/examples/webapp/lib/Example2Form.php <==
<?php
/**
 * ͸ڡʥХǡ˥ץ2Υե९饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: Example2Form.php,v 1.1 2007/07/08 04:22:38 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class Example2Form extends SyL_ActionForm
{
    var $form_config = array(
        'lastname' => array(
            'type'         => 'text',
            'display_name' => '̾',
            'attributes'   => array('size' => '30'),
            'validate'     => array(
                'require' => array(
                    'message' => '{name}ɬܤǤ'
                ),
                'length' => array(
                    'message'    => '{name}Ϻ{max}ʸʥХȡˤޤϤǤޤ',
                    'parameters' => array('max' => 20)
                )
            )
        ),
        'firstname' => array(
            'type'         => 'text',
            'display_name' => '̾̾',
            'attributes'   => array('size' => '30'),
            'validate'     => array(
                'require' => array(
                    'message' => '{name}ɬܤǤ'
                ),
                'length' => array(
                    'message'    => '{name}Ϻ{max}ʸʥХȡˤޤϤǤޤ',
                    'parameters' => array('max' => 20)
                )
            )
        ),
        'gender' => array(
            'type'         => 'radio',
            'display_name' => '',
            'options'      => array(
                '1' => '',
                '2' => ''
            ),
            'validate'     => array(
                'require' => array(
                    'message' => '{name}ɬܤǤ'
                )
            )
        ),
        'prefecture' => array(
            'type'         => 'select',
            'display_name' => 'ƻܸ',
            'options'      => array(
                ''   => '򤷤Ƥ',
                '01' => '̳ƻ',
                '02' => 'Ŀ',
                '03' => '긩',
                '04' => 'ܾ븩',
                '05' => 'ĸ',
                '06' => '',
                '07' => 'ʡ縩',
                '08' => '븩',
                '09' => 'ڸ',
                '10' => 'ϸ',
                '11' => '̸',
                '12' => 'ո',
                '13' => '',
                '14' => '',
                '15' => '㸩',
                '16' => 'ٻ',
                '17' => '',
                '18' => 'ʡ温',
                '19' => '',
                '20' => 'Ĺ',
                '21' => '츩',
                '22' => 'Ų',
                '23' => 'θ',
                '24' => 'Ÿ',
                '25' => '츩',
                '26' => '',
                '27' => '',
                '28' => 'ʼ˸',
                '29' => 'ɸ',
                '30' => '²λ',
                '31' => 'Ļ踩',
                '32' => '纬',
                '33' => '',
                '34' => '縩',
                '35' => '',
                '36' => '縩',
                '37' => '',
                '38' => 'ɲ',
                '39' => 'θ',
                '40' => 'ʡ',
                '41' => '츩',
                '42' => 'Ĺ긩',
                '43' => 'ܸ',
                '44' => 'ʬ',
                '45' => 'ܺ긩',
                '46' => '縩',
                '47' => '츩'
            ),
            'validate'     => array(
                'require' => array(
                    'message' => '{name}ɬܤǤ'
                )
            )
        ),
        'tel' => array(
            'type'         => 'text',
            'display_name' => 'ֹ',
            'attributes'   => array('size' => '20'),
            'validate'     => array(
                'regex' => array(
                    'message' => '{name}ޤ',
                    'parameters' => array('format'=> '/^[0-9]+\-[0-9]+\-[0-9]{4}$/')
                )
            )
        ),
        'mailaddress' => array(
            'type'         => 'text',
            'display_name' => '᡼륢ɥ쥹',
            'attributes'   => array('size' => '30'),
            'validate'     => array(
                'require' => array(
                    'message' => '{name}ɬܤǤ'
                ),
                'email' => array(
                    'message' => '{name}ηޤ'
                )
            )
        ),
        'blowser' => array(
            'type'         => 'checkbox',
            'display_name' => '褯Ѥ֥饦',
            'attributes'   => array('separator' => '<br>'),
            'options'      => array(
                '01' => 'Internet Explorer',
                '02' => 'Fire Fox',
                '03' => 'Opera',
                '04' => 'Safari',
            )
        )

    );
}

?>

==> SyL-0.13.0.tar.gz: SyL/example/examples/webapp/lib/Example2Form.php <==
<?php
/**
 * ͸ڡʥХǡ˥ץ2Υե९饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: Example2Form.php,v 1.2 2007/07/29 08:55:00 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class Example2Form extends SyL_ActionForm
{
    var $elements_config = array(
        'lastname' => array(
            'type'         => 'text',
            'name' => '̾',
            'attributes'   => array('size' => '30'),
            'validate'     => array(
                'require' => array(
                    'message' => '{name}ɬܤǤ'
                ),
                'length' => array(
                    'message'    => '{name}Ϻ{max}ʸʥХȡˤޤϤǤޤ',
                    'parameters' => array('max' => 20)
                )
            )
        ),
        'firstname' => array(
            'type'         => 'text',
            'name' => '̾̾',
            'attributes'   => array('size' => '30'),
            'validate'     => array(
                'require' => array(
                    'message' => '{name}ɬܤǤ'
                ),
                'length' => array(
                    'message'    => '{name}Ϻ{max}ʸʥХȡˤޤϤǤޤ',
                    'parameters' => array('max' => 20)
                )
            )
        ),
        'gender' => array(
            'type'         => 'radio',
            'name' => '',
            'options'      => array(
                '1' => '',
                '2' => ''
            ),
            'validate'     => array(
                'require' => array(
                    'message' => '{name}ɬܤǤ'
                )
            )
        ),
        'prefecture' => array(
            'type'         => 'select',
            'name' => 'ƻܸ',
            'options'      => array(
                ''   => '򤷤Ƥ',
                '01' => '̳ƻ',
                '02' => 'Ŀ',
                '03' => '긩',
                '04' => 'ܾ븩',
                '05' => 'ĸ',
                '06' => '',
                '07' => 'ʡ縩',
                '08' => '븩',
                '09' => 'ڸ',
                '10' => 'ϸ',
                '11' => '̸',
                '12' => 'ո',
                '13' => '',
                '14' => '',
                '15' => '㸩',
                '16' => 'ٻ',
                '17' => '',
                '18' => 'ʡ温',
                '19' => '',
                '20' => 'Ĺ',
                '21' => '츩',
                '22' => 'Ų',
                '23' => 'θ',
                '24' => 'Ÿ',
                '25' => '츩',
                '26' => '',
                '27' => '',
                '28' => 'ʼ˸',
                '29' => 'ɸ',
                '30' => '²λ',
                '31' => 'Ļ踩',
                '32' => '纬',
                '33' => '',
                '34' => '縩',
                '35' => '',
                '36' => '縩',
                '37' => '',
                '38' => 'ɲ',
                '39' => 'θ',
                '40' => 'ʡ',
                '41' => '츩',
                '42' => 'Ĺ긩',
                '43' => 'ܸ',
                '44' => 'ʬ',
                '45' => 'ܺ긩',
                '46' => '縩',
                '47' => '츩'
            ),
            'validate'     => array(
                'require' => array(
                    'message' => '{name}ɬܤǤ'
                )
            )
        ),
        'tel' => array(
            'type'         => 'text',
            'name' => 'ֹ',
            'attributes'   => array('size' => '20'),
            'validate'     => array(
                'regex' => array(
                    'message' => '{name}ޤ',
                    'parameters' => array('format'=> '/^[0-9]+\-[0-9]+\-[0-9]{4}$/')
                )
            )
        ),
        'mailaddress' => array(
            'type'         => 'text',
            'name' => '᡼륢ɥ쥹',
            'attributes'   => array('size' => '30'),
            'validate'     => array(
                'require' => array(
                    'message' => '{name}ɬܤǤ'
                ),
                'email' => array(
                    'message' => '{name}ηޤ'
                )
            )
        ),
        'blowser' => array(
            'type'         => 'checkbox',
            'name' => '褯Ѥ֥饦',
            'attributes'   => array('separator' => '<br>'),
            'options'      => array(
                '01' => 'Internet Explorer',
                '02' => 'Fire Fox',
                '03' => 'Opera',
                '04' => 'Safari',
            )
        )

    );
}

?>
